# 微积分计算器CalculusCalculator
使用Python开发的微积分计算器.

通过Python第三方库Sympy实现了一些简单的微积分和常规代数运算.

通过Python第三方库PySide6实现了UI界面.

此外,还有CalculusWeb,即本软件的网页端.参见https://limingkang.pythonanywhere.com.

该项目业已发布于Github，链接：https://github.com/limingkang12345/CalculusCalculator/

# 主要功能介绍
目前v1.4版本支持7种功能：求导,积分,变形和解方程(组)与解不等式(组).

其中求导包括显函数求导及隐函数求导.

积分包括不定积分和定积分.

变形包括多种代数式合并,展开,因式分解.

解方程和解不等式支持指定变量范围范围,还支持微分方程求解.

解方程组支持多元任意次方程组,解不等式组只支持一元不等式组求解.

# 程序优点
1.轻量化(至少源码是这样的)

2.页面简洁(其实就是不想好好做UI)

3.简单易用

# 程序缺点
1.功能单一(还将继续完善)

2.启动速度慢(这个和Python有很大关系)

3.可执行二进制文件体积较大(这个和打包器有很大关系)

# 使用教程

### 目前输入规范已经嵌入软件"帮助"选项卡内

运行前请关闭所有杀毒软件和防火墙(当然目前来看一般不会被杀毒软件拦截)!

安装成功后直接在命令行运行CalculusCalculator即可(当然首先要确保你的Python环境和PATH配置正确).

# 源码依赖
需要PySide6和Sympy库.

# 常见问题
可执行二进制文件无法运行:请将您的运行环境描述与错误信息提交至Github Issue

点击按钮后无反应:检查您输入的表达式,若仍无法解决请将程序窗口截图提交至Github Issue
